blueair: An Unofficial Blueair Python client
============================================

The `blueair` package contains an unofficial Python client for the Blueair air purifiers. It can be used both as a library and as a standalone command line utility. When running the command line utility graphs can be generated showing historical data.

Installation
------------

First of all, ensure you are running Python 3.7 or newer. Installation of the package is as simple as running:

.. code-block:: console

   $ pip install blueair

After running this command the `blueair` package is available for importing in Python, and the command line interface can be accessed by running `python -m blueair`.

Compatibility
-------------

This package is inteded to be used with Python 3.7 or newer. It has been annotated with type extensions and supports PEP 561 typed packages.

Disclaimer
----------

The software is provided "as is", without warranty of any kind, express or implied, including but not limited to the warranties of merchantability, fitness for a particular purpose and noninfringement. In no event shall the authors or copyright holders be liable for any claim, damages or other liability, whether in an action of contract, tort or otherwise, arising from, out of or in connection with the software or the use or other dealings in the software.

This package and its authors are not affiliated by Blueair. For support regarding this package, please do not contact Blueair but instead file an issue using the package repository's issue tracker.

This package has only been tested using a Blueair Classic 280i air purifier located somewhere in Europe. It may or may not work for different models or locations.

Acknowledgements
----------------

This package would not exist without the work of @mylesagray, who created a Blueair homebridge plugin that can be found at https://github.com/mylesagray/homebridge-blueair.

License
-------

This package is released under the terms of the MIT license. A copy of the license can be found in the package repository.
